﻿using System;
using System.Collections.Generic;
using System.Linq;
using System.Text;
using System.Threading.Tasks;
using System.Windows;
using System.Windows.Controls;
using System.Windows.Data;
using System.Windows.Documents;
using System.Windows.Input;
using System.Windows.Media;
using System.Windows.Media.Imaging;
using System.Windows.Navigation;
using System.Windows.Shapes;
using GrapeCity.Windows.SpreadSheet.Data;

namespace StockTrends.WPF
{
    /// <summary>
    /// Interaction logic for MainWindow.xaml
    /// </summary>
    public partial class MainWindow : Window
    {
        public MainWindow()
        {
            //InitializeComponent();
        }
        private void btnLoadSpreadsheet_Click(object sender, RoutedEventArgs e)
        {
            Microsoft.Win32.OpenFileDialog ofd = new Microsoft.Win32.OpenFileDialog();
            ofd.DefaultExt = ".xlsx";
            ofd.Filter = "Excel Documents (*.xlsx)|*.xlsx";
            var sel = ofd.ShowDialog();
            if (sel == true)
            {
                //one line of code to import the Excel file into Spread.NET  
                spreadControl.OpenExcel(ofd.FileName);
                ProcessSpreadsheet();
            }
        }
        private void btnExportSpreadsheet_Click(object sender, RoutedEventArgs e)
        {
            Microsoft.Win32.SaveFileDialog sfd = new Microsoft.Win32.SaveFileDialog();
            sfd.FileName = "SpreadNET.xlsx";
            sfd.Filter = "Excel Documents (*.xlsx)|*.xlsx";
            sfd.DefaultExt = ".xlsx";
            var sel = sfd.ShowDialog();
            if (sel == true)
            {
                spreadControl.SaveExcel(sfd.FileName,
                    GrapeCity.Windows.SpreadSheet.Data.ExcelFileFormat.XLSX);
            }
        }
        private void ProcessSpreadsheet()
        {
            List<string> stocks = new List<string>();
            var worksheet = spreadControl.Sheets[0];
            for (var i = 0; i < worksheet.RowCount; i++)
            {
                var stockSymbol = worksheet.Cells[i, 0].Text;
                stocks.Add(stockSymbol);
            }
            StockHistoryRetriever retriever = new StockHistoryRetriever();
            var data = retriever.Get3MonthHistory(stocks);
            //calculate max columns required,  
            //increase the number of columns available in the worksheet  
            int maxCount = data.Max(x => x.Prices.Count());
            //1 column for the symbol, 1 column for the sparkline  
            worksheet.ColumnCount = maxCount + 2;
            //set sparkline column width  
            worksheet.Columns[1].Width = 500;

            //define header column style  
            var headerStyleName = "HeaderStyle";
            var headerStyle = new StyleInfo()
            {
                Background = new SolidColorBrush(Colors.LightSeaGreen),
                Name = headerStyleName,
                BorderBottom = new BorderLine(Colors.SeaGreen),
                BorderRight = new BorderLine(Colors.SeaGreen)
            };
            worksheet.NamedStyles.Add(headerStyle);
            //set column header for the symbol and sparkline column - assign header style  
            worksheet.ColumnHeader.Cells[0, 0].Text = "Symbol";
            worksheet.ColumnHeader.Cells[0, 0].StyleName = headerStyleName;
            worksheet.ColumnHeader.Cells[0, 1].Text = "Trend";
            worksheet.ColumnHeader.Cells[0, 1].StyleName = headerStyleName;
            bool setHeader = true;
            foreach (var stock in data)
            {
                //find stock index  
                int rowIdx = 0;
                int colIdx = 0;
                spreadControl.Search(0, stock.Symbol, out rowIdx, out colIdx);
                int columnCounter = 2;
                foreach (var price in stock.Prices)
                {
                    //set header to date, expand column width, set column header style  
                    if (setHeader)
                    {
                        worksheet.ColumnHeader.Cells[0, columnCounter].Text =
                            price.Date.ToString("MM/dd/yyyy");
                        worksheet.ColumnHeader.Cells[0, columnCounter].StyleName =
                            headerStyleName;
                        worksheet.Columns[columnCounter].Width = 85;
                    }

                    //set cell to format to currency  
                    worksheet.Cells[rowIdx, columnCounter].Formatter =
                        new GeneralFormatter(FormatMode.StandardNumericMode, "c");
                    worksheet.Cells[rowIdx, columnCounter].Value = price.Price;
                    columnCounter++;
                }
                setHeader = false;

                //create sparkline  
                var range = new CellRange(rowIdx, 2, 1, stock.Prices.Count);
                var settings = new SparklineSetting();
                settings.AxisColor = SystemColors.ActiveBorderColor;
                settings.LineWeight = 1;
                settings.ShowMarkers = true;
                settings.MarkersColor = Color.FromRgb(255, 0, 128);
                settings.ShowFirst = true;
                settings.ShowHigh = true;
                settings.ShowLast = true;
                settings.ShowNegative = true;
                settings.FirstMarkerColor = Color.FromRgb(163, 73, 164);
                settings.HighMarkerColor = Color.FromRgb(49, 78, 111);
                settings.LastMarkerColor = Color.FromRgb(0, 255, 255);
                settings.NegativeColor = Color.FromRgb(255, 255, 0);
                //set row height  
                worksheet.Rows[rowIdx].Height = 250;
                worksheet.SetSparkline(rowIdx, 1, range, DataOrientation.Horizontal,
                    SparklineType.Line, settings);
                spreadControl.Invalidate();
            }
        }
    }
}
