﻿using Newtonsoft.Json.Linq;
using RestSharp;
using System;
using System.Collections.Generic;

namespace StockTrends.WPF
{
    public class StockHistoryRetriever
    {
        private const string API_TOKEN = "<YOUR PUBLISHABLE API TOKEN>";
        private const string BASE_URL = "https://cloud.iexapis.com";
        private const string API_VERSION = "beta";

        public List<ClosingStockHistory> Get3MonthHistory(List<string> symbols)
        {
            var client = new RestClient(BASE_URL);
            var endpoint = $"{API_VERSION}/stock/market/batch";
            var request = new RestRequest(endpoint, Method.Get);
            request.AddQueryParameter("symbols", string.Join(",", symbols));
            request.AddQueryParameter("types", "chart");
            request.AddQueryParameter("range", "3m");
            request.AddQueryParameter("chartCloseOnly", "true");
            request.AddQueryParameter("token", API_TOKEN);

            RestResponse resp = client.Execute(request);
            var stockHistory = JObject.Parse(resp.Content);

            var history = new List<ClosingStockHistory>();
            foreach (var symbol in symbols)
            {
                if (symbol == "")
                    continue;
                var closingStockHistory = new ClosingStockHistory();
                closingStockHistory.Symbol = symbol;
                closingStockHistory.Prices = new List<ClosingPrice>();
                var stock = stockHistory[symbol];
                var chartData = (JArray)stock["chart"];
                foreach (var itm in chartData)
                {
                    closingStockHistory.Prices.Add(new ClosingPrice()
                    {
                        Date = Convert.ToDateTime(itm["date"]),
                        Price = Convert.ToDouble(itm["close"])
                    });
                }
                history.Add(closingStockHistory);
            }

            return history;
        }
    }

    public class ClosingStockHistory
    {
        public string Symbol { get; set; }
        public List<ClosingPrice> Prices { get; set; }
    }

    public class ClosingPrice
    {
        public DateTime Date { get; set; }
        public double Price { get; set; }
    }
}
