﻿Imports GrapeCity.Windows.SpreadSheet.Data
Class MainWindow
    Private Sub btnLoadSpreadsheet_Click(sender As Object, e As RoutedEventArgs) Handles btnLoadSpreadsheet.Click
        Dim ofd As Microsoft.Win32.OpenFileDialog = New Microsoft.Win32.OpenFileDialog()
        ofd.DefaultExt = ".xlsx"
        ofd.Filter = "Excel Documents (*.xlsx)|*.xlsx"
        Dim sel = ofd.ShowDialog()
        If (sel = True) Then
            ' one line of code to import the Excel file into Spread.NET  
            spreadControl.OpenExcel(ofd.FileName)
            ProcessSpreadsheet()
        End If
    End Sub
    Private Sub btnExportSpreadsheet_Click(sender As Object, e As RoutedEventArgs) Handles btnExportSpreadsheet.Click
        Dim sfd As Microsoft.Win32.SaveFileDialog = New Microsoft.Win32.SaveFileDialog()
        sfd.FileName = "SpreadNET.xlsx"
        sfd.Filter = "Excel Documents (*.xlsx)|*.xlsx"
        sfd.DefaultExt = ".xlsx"
        Dim sel = sfd.ShowDialog()
        If (sel = True) Then
            spreadControl.SaveExcel(sfd.FileName, GrapeCity.Windows.SpreadSheet.Data.ExcelFileFormat.XLSX)
        End If
    End Sub
    Private Sub ProcessSpreadsheet()
        Dim stocks As New List(Of String)
        Dim worksheet = spreadControl.Sheets(0)
        For i As Integer = 0 To worksheet.RowCount - 1
            Dim stockSymbol = worksheet.Cells(i, 0).Text
            stocks.Add(stockSymbol)
        Next
        Dim retriever As StockHistoryRetriever = New StockHistoryRetriever()
        Dim data = retriever.Get3MonthHistory(stocks)
        ' calculate max columns required
        ' increase the number of columns available in the worksheet
        Dim maxCount As Integer = data.Max(Function(x) x.Prices.Count)
        ' 1 column for the symbol, 1 column for the sparkline
        worksheet.ColumnCount = maxCount + 2
        ' set sparkline column width
        worksheet.Columns(1).Width = 500
        ' similar to a CSS class, define header column style
        Dim headerStyleName = "HeaderStyle"
        Dim headerStyle As New StyleInfo With {.Background = New SolidColorBrush(Colors.LightSeaGreen), .Name = headerStyleName, .BorderBottom = New BorderLine(Colors.SeaGreen), .BorderRight = New BorderLine(Colors.SeaGreen)}
        worksheet.NamedStyles.Add(headerStyle)
        ' set column header for the symbol and sparkline column - assign header style  
        worksheet.ColumnHeader.Cells(0, 0).Text = "Symbol"
        worksheet.ColumnHeader.Cells(0, 0).StyleName = headerStyleName
        worksheet.ColumnHeader.Cells(0, 1).Text = "Trend"
        worksheet.ColumnHeader.Cells(0, 1).StyleName = headerStyleName
        Dim setHeader = True
        For Each stock In data
            ' find stock index
            Dim rowIdx = 0
            Dim colIdx = 0
            spreadControl.Search(0, stock.Symbol, rowIdx, colIdx)
            Dim columnCounter = 2
            For Each price In stock.Prices
                If setHeader Then
                    ' set header text to date of the price,
                    ' expand column width, set column header style
                    worksheet.ColumnHeader.Cells(0, columnCounter).Text = price.ClosingDate.ToString("MM/dd/yyyy")
                    worksheet.ColumnHeader.Cells(0, columnCounter).StyleName = headerStyleName
                    worksheet.Columns(columnCounter).Width = 85
                End If
                ' set cell format to currency
                worksheet.Cells(rowIdx, columnCounter).Formatter = New GeneralFormatter(FormatMode.StandardNumericMode, "c")
                worksheet.Cells(rowIdx, columnCounter).Value = price.Price
                columnCounter += 1
            Next
            setHeader = False
            ' create the sparkline
            Dim range = New CellRange(rowIdx, 2, 1, stock.Prices.Count)
            Dim settings = New SparklineSetting()
            settings.AxisColor = SystemColors.ActiveBorderColor
            settings.LineWeight = 1
            settings.ShowMarkers = True
            settings.ShowFirst = True
            settings.ShowHigh = True
            settings.ShowLast = True
            settings.ShowNegative = True
            settings.FirstMarkerColor = Color.FromArgb(255, 163, 73, 164)
            settings.HighMarkerColor = Color.FromArgb(255, 49, 78, 111)
            settings.LastMarkerColor = Color.FromArgb(255, 0, 255, 255)
            settings.NegativeColor = Color.FromArgb(255, 255, 255, 0)
            ' set row height
            worksheet.Rows(rowIdx).Height = 250
            worksheet.SetSparkline(rowIdx, 1, range, DataOrientation.Horizontal, SparklineType.Line, settings)
            spreadControl.Invalidate()
        Next
    End Sub
End Class
